@@ -883,13 +883,11 @@ void labelbbox(labelptr labox, XPoint *npoints, objinstptr callinst)
 		+ tmpext.descent;
    points[1].y = points[2].y = points[0].y + tmpext.ascent - tmpext.descent;
 
-#ifdef SCHEMA
    /* separate bounding box for pinlabels and infolabels */
 
    if (labox->pin)
       for (j = 0; j < 4; j++)
 	 pinadjust(labox->justify, &points[j].x, &points[j].y, 1);
-#endif
 
    UTransformPoints(points, npoints, 4, labox->position,
 		labox->scale, labox->rotation); 
@@ -934,7 +932,6 @@ void calcbboxsingle(genericptr *bboxgen, objinstptr thisinst,
 
       case(LABEL):
 	 {
-#ifdef SCHEMA
 	    /* because a pin is offset from its position point, include */
 	    /* that point in the bounding box.				*/
 
@@ -942,7 +939,6 @@ void calcbboxsingle(genericptr *bboxgen, objinstptr thisinst,
                bboxcalc(TOLABEL(bboxgen)->position.x, llx, urx);
                bboxcalc(TOLABEL(bboxgen)->position.y, lly, ury);
 	    }
-#endif
 	    labelbbox(TOLABEL(bboxgen), npoints, thisinst);
 
             for (j = 0; j < 4; j++) {
@@ -1033,7 +1029,6 @@ void updatepagebounds(objectptr thisobject)
    }
 }
 
-#ifdef SCHEMA
 /*--------------------------------------------------------------*/
 /* Free memory for the schematic bounding box                   */
 /*--------------------------------------------------------------*/
@@ -1045,7 +1040,6 @@ void invalidateschembbox(objinstptr thisinst)
       thisinst->schembbox = NULL;
    }
 }
-#endif
 
 /*--------------------------------------------------------------*/
 /* Calculate the bounding box for an object instance.  Use the	*/
@@ -1061,10 +1055,8 @@ void calcbboxinst(objinstptr thisinst)
    genericptr *gelem;
    short llx, lly, urx, ury;
 
-#ifdef SCHEMA
    short pllx, plly, purx, pury;
    Boolean hasschembbox = FALSE;
-#endif 
 
    if (thisinst == NULL) return;
 
@@ -1075,14 +1067,11 @@ void calcbboxinst(objinstptr thisinst)
    urx = llx + thisobj->bbox.width;
    ury = lly + thisobj->bbox.height;
 
-#ifdef SCHEMA
    pllx = plly = 32767;
    purx = pury = -32768;
-#endif
 
    for (gelem = thisobj->plist; gelem < thisobj->plist + thisobj->parts;
 		gelem++) {
-#ifdef SCHEMA
       /* pins which do not appear outside of the object	*/
       /* contribute to the objects "schembbox".		*/
 
@@ -1094,7 +1083,6 @@ void calcbboxinst(objinstptr thisinst)
 	    continue;
 	 }
       }
-#endif
 
       if (has_param(*gelem))
 	 calcbboxsingle(gelem, thisinst, &llx, &lly, &urx, &ury);
@@ -1105,7 +1093,6 @@ void calcbboxinst(objinstptr thisinst)
    thisinst->bbox.width = urx - llx;
    thisinst->bbox.height = ury - lly;
 
-#ifdef SCHEMA
    if (hasschembbox) {
       if (thisinst->schembbox == NULL)
          thisinst->schembbox = (BBox *)malloc(sizeof(BBox));
@@ -1117,8 +1104,6 @@ void calcbboxinst(objinstptr thisinst)
    }
    else
       invalidateschembbox(thisinst);
-#endif
-
 }
 
 /*--------------------------------------------------------------*/
@@ -1232,7 +1217,6 @@ void calcbboxvalues(objinstptr thisinst, genericptr *newelement)
       if (newelement != NULL) bboxgen = newelement;
 
       if ((thisobj->params == NULL) || (!has_param(*bboxgen))) {
-#ifdef SCHEMA
 	 /* pins which do not appear outside of the object 	*/
 	 /* are ignored now---will be computed per instance.	*/
 
@@ -1242,7 +1226,6 @@ void calcbboxvalues(objinstptr thisinst, genericptr *newelement)
 	       goto nextgen;
 	    }
 	 }
-#endif
 	 calcbboxsingle(bboxgen, thisinst, &llx, &lly, &urx, &ury);
       }
 nextgen:
@@ -1296,9 +1279,7 @@ void centerview(objinstptr tinst)
    corner.x = origin.x + tinst->bbox.width;
    corner.y = origin.y + tinst->bbox.height;
 
-#ifdef SCHEMA
    extendschembbox(tinst, &origin, &corner);
-#endif
 
    width = corner.x - origin.x;
    height = corner.y - origin.y;
@@ -1437,8 +1418,6 @@ void UDrawX(labelptr curlabel)
    UDrawXAt(&wpt);
 }
 
-#ifdef SCHEMA
-
 /*----------------------------------------------------------------------*/
 /* Draw "X" on top level (only for LOCAL and GLOBAL pin labels)		*/
 /*----------------------------------------------------------------------*/
@@ -1543,8 +1522,6 @@ void pinadjust (short justify, short *xpoint, short *ypoint, short dir)
    if (ypoint != NULL) *ypoint += (dir > 0) ? dely : -dely;
 }
 
-#endif
-
 /*----------------------------------------------------------------------*/
 /* Draw line for editing text (position of cursor in string is given by */
 /*   tpos (2nd parameter)						*/
@@ -1579,12 +1556,10 @@ void UDrawTextLine(labelptr curlabel, short tpos)
    points[1].x = points[0].x;
    points[1].y = points[0].y + TEXTHEIGHT + 6;
 
-#ifdef SCHEMA
    if (curlabel->pin) {
       pinadjust(tmpjust, &(points[0].x), &(points[0].y), 1);
       pinadjust(tmpjust, &(points[1].x), &(points[1].y), 1);
    }
-#endif
 
    /* draw the line */
 
@@ -1669,10 +1644,8 @@ void UDrawBBox()
    corner.x = origin.x + bbinst->bbox.width;
    corner.y = origin.y + bbinst->bbox.height;
 
-#ifdef SCHEMA
    /* Include any schematic labels in the bounding box.	*/
    extendschembbox(bbinst, &origin, &corner);
-#endif
 
    user_to_window(origin, &worig);
    user_to_window(corner, &wcorn);
@@ -1935,16 +1908,12 @@ void UDrawObject(objinstptr theinstance, short level, int passcolor, pushlistptr
 	     break;
    
   	  case(LABEL): 
-#ifdef SCHEMA
 	     if (level == 0 || TOLABEL(areagen)->pin == False ||
 			(TOLABEL(areagen)->justify & PINVISIBLE))
-#endif
              UDrawString(TOLABEL(areagen), curcolor, theinstance);
-#ifdef SCHEMA
 	     else if (level == 1 && TOLABEL(areagen)->pin &&
 			TOLABEL(areagen)->pin != INFO && areastruct.pinpointon)
 		UDrawXDown(TOLABEL(areagen));
-#endif
 	     break;
        }
      }
@@ -1998,10 +1967,8 @@ void UDoLatex(objinstptr theinstance, short level, FILE *f,
    
 	 case(LABEL): 
 	    thislabel = TOLABEL(areagen);
-#ifdef SCHEMA
 	    if (level == 0 || thislabel->pin == False ||
 			(thislabel->justify & PINVISIBLE))
-#endif
 		if (thislabel->justify & LATEXLABEL) {
 		    if (checkonly) {
 		       *checkonly = TRUE;
@@ -2079,14 +2046,8 @@ void TopDoLatex()
    psscale = getpsscale(xobjs.pagelist[areastruct.page]->outscale,
 		areastruct.page);
 
-#ifdef SCHEMA
    width = toplevelwidth(areastruct.topinstance, &origin.x);
    height = toplevelheight(areastruct.topinstance, &origin.y);
-#else
-   width = topobject->bbox.width;
-   height = topobject->bbox.height;
-   origin = topobject->bbox.lowerleft;
-#endif
 
    tx = (int)(72 / psscale) - origin.x,
    ty = (int)(72 / psscale) - origin.y;
