@@ -82,15 +82,11 @@ static char *function_names[NUM_FUNCTIONS + 1] = {
    "Pan Down", "Write", "Rotate", "Flip X", "Flip Y", "Snap", "Snap To",
    "Pop", "Push", "Delete", "Select", "Box", "Arc", "Text",
    "Exchange", "Copy", "Join", "Unjoin", "Spline", "Edit",
-   "Undelete", "Select Save", "Unselect", "Dashed", "Dotted",
+   "Undo", "Redo", "Select Save", "Unselect", "Dashed", "Dotted",
    "Solid", "Prompt", "Dot", "Wire", "Start", "Finish", "Cancel",
    "Nothing", "Exit",
-
-#ifdef SCHEMA
    "Netlist", "Swap", "Pin Label", "Pin Global", "Info Label",
    "Connectivity", "Sim", "SPICE", "PCB", "SPICE Flat",
-#endif
-
    NULL			/* sentinel */
 };
 
@@ -623,7 +619,8 @@ void default_keybindings()
    add_binding(XK_J, XCF_Unjoin);
    add_binding(XK_s, XCF_Spline);
    add_binding(XK_e, XCF_Edit);
-   add_binding(XK_u, XCF_Undelete);
+   add_binding(XK_u, XCF_Undo);
+   add_binding(XK_U, XCF_Redo);
    add_binding(XK_M, XCF_Select_Save);
    add_binding(XK_m, XCF_Select_Save);
    add_binding(XK_x, XCF_Unselect);
@@ -641,8 +638,6 @@ void default_keybindings()
    add_binding(BUTTON2, XCF_Finish);
    add_binding(BUTTON3, XCF_Cancel);
    add_binding(ALT | XK_s, XCF_SnapTo);
-
-#ifdef SCHEMA
    add_binding(ALT | XK_q, XCF_Netlist);
    add_binding(XK_slash, XCF_Swap);
    add_binding(XK_T, XCF_Pin_Label);
@@ -657,7 +652,6 @@ void default_keybindings()
 /* add_binding(ALT | XK_a, XCF_SPICE);		*/
 /* add_binding(ALT | XK_f, XCF_SPICEflat);	*/
 /* add_binding(ALT | XK_p, XCF_PCB);		*/
-#endif
 
 }
 
