@@ -146,7 +146,7 @@ menustruct Colors[] = {
 
 menustruct Parameterize[] = {
 	{"Substring", action(promptparam, NULL)},
-	{"Position", action(startparam, Number(P_POSITION))},
+	{"Numeric", action(startparam, Number(P_NUMERIC))},
 	{"Style", action(startparam, Number(P_STYLE))},
 	{"Justification", action(startparam, Number(P_JUSTIFY))},
 	{"Start Angle", action(startparam, Number(P_ANGLE1))},
@@ -156,6 +156,8 @@ menustruct Parameterize[] = {
 	{"Rotation", action(startparam, Number(P_ROTATION))},
 	{"Scale", action(startparam, Number(P_SCALE))},
 	{"Linewidth", action(startparam, Number(P_LINEWIDTH))},
+	{"Color", action(startparam, Number(P_COLOR))},
+	{"Position", action(startparam, Number(P_POSITION))},
 };
 
 menustruct Stipples[] = {
@@ -240,7 +242,6 @@ menustruct SnapMenu[] = {
         {"Snap spacing", action(getsnapspace, NULL)},
 };
 
-#ifdef SCHEMA
 menustruct PinConvert[] = {
 	{"Normal label", action(dopintype, Number(NORMAL))},
 	{"Local Pin", action(dopintype, Number(LOCAL))},
@@ -258,14 +259,13 @@ menustruct SchemaMenu[] = {
 	{"Make Matching Symbol", action(dobeforeswap, NULL)},
 	{"Associate with Symbol", action(startschemassoc, Number(1))},
 	{"Highlight Connectivity", action(startconnect, NULL)},
-	{"Auto-number Components", action(callgennet, Number(4))},
+	{"Auto-number Components", action(callwritenet, Number(4))},
 	{" ", noaction},
-	{"Write spice", action(callgennet, Number(0))},
-	{"Write flattened spice", action(callgennet, Number(3))},
-	{"Write sim", action(callgennet, Number(1))},
-	{"Write pcb", action(callgennet, Number(2))},
+	{"Write spice", action(callwritenet, Number(0))},
+	{"Write flattened spice", action(callwritenet, Number(3))},
+	{"Write sim", action(callwritenet, Number(1))},
+	{"Write pcb", action(callwritenet, Number(2))},
 };
-#endif
 
 menustruct WindowMenu[] = {
 	{"Zoom In (Z)", action(zoominrefresh, NULL)},
@@ -286,6 +286,9 @@ menustruct FileMenu[] = {
 	{"Read Xcircuit File", action(getfile, Number(NORMAL))},
 	{"Import Xcircuit PS", action(getfile, Number(IMPORT))},
 	{"Import background PS", action(getfile, Number(PSBKGROUND))},
+#ifdef ASG
+	{"Import SPICE deck", action(getfile, Number(IMPORTSPICE))},
+#endif
 	{"Execute script", action(getfile, Number(SCRIPT))},
 	{"Write Xcircuit PS (W)", action(outputpopup, NULL)},
 	{" ", noaction},
@@ -302,10 +305,8 @@ menustruct OptionMenu[] = {
 	{"Alt Colors", action(inversecolor, &areastruct.invert)},
 	{"Show Bounding box", action(toggle, &areastruct.bboxon)},
 	{"Edit in place", setaction(toggle, &areastruct.editinplace)},
-#ifdef SCHEMA
 	{"Show Pin Positions", action(toggle, &areastruct.pinpointon)},
 	{"Enable XSchema", action(doxschema, Number(1))},
-#endif
 #ifdef HAVE_XPM
 	{"Disable Toolbar", action(dotoolbar, NULL)},
 #endif
@@ -342,9 +343,7 @@ menustruct TopButtons[] = {
 	{"Text", submenu(TextMenu)},
 	{"Options", submenu(OptionMenu)},
 	{"Window", submenu(WindowMenu)},
-#ifdef SCHEMA
 	{"Netlist", submenu(SchemaMenu)},
-#endif
 };
 
 short maxbuttons = sizeof(TopButtons) / sizeof(menustruct);
